==> staticsite_1.0.orig.tar.gz: staticsite-1.0/staticsite/features/j2.py <==
from staticsite.page import Page
from staticsite.rendered import RenderedString
from staticsite.feature import Feature
import os
import logging

log = logging.getLogger()


class IgnorePage(Exception):
    pass


class J2Pages(Feature):
    def try_load_page(self, root_abspath, relpath):
        basename = os.path.basename(relpath)
        if ".j2." not in basename:
            return None
        try:
            return J2Page(self, root_abspath, relpath)
        except IgnorePage:
            return None


class J2Page(Page):
    TYPE = "jinja2"

    RENDER_PREFERRED_ORDER = 2

    def __init__(self, j2env, root_abspath, relpath):
        dirname, basename = os.path.split(relpath)
        dst_basename = basename.replace(".j2", "")
        dst_relpath = os.path.join(dirname, dst_basename)

        if dst_basename == "index.html":
            linkpath = dirname
        else:
            linkpath = os.path.join(dirname, dst_basename)

        super().__init__(
            site=j2env.site,
            root_abspath=root_abspath,
            src_relpath=relpath,
            src_linkpath=linkpath,
            dst_relpath=dst_relpath,
            dst_link=os.path.join(j2env.site.settings.SITE_ROOT, linkpath))

        self.meta["date"] = self.site.generation_time

    def render(self):
        with open(self.src_abspath, "rt") as fd:
            template_body = fd.read()
        try:
            template = self.site.theme.jinja2.from_string(template_body)
        except Exception:
            log.exception("%s: cannot load template", self.src_relpath)
            raise IgnorePage
        body = template.render(
            page=self,
        )
        return {
            self.dst_relpath: RenderedString(body),
        }

==> staticsite_1.1.orig.tar.gz: staticsite-1.1/staticsite/features/j2.py <==
from __future__ import annotations
from staticsite.page import Page
from staticsite.render import RenderedString
from staticsite.feature import Feature
from staticsite.file import File
import os
import logging

log = logging.getLogger()


class IgnorePage(Exception):
    pass


class J2Pages(Feature):
    """
    Render jinja2 templates from the contents directory.

    See doc/templates.md for details.
    """
    RUN_BEFORE = ["tags"]

    def try_load_page(self, src: File):
        basename = os.path.basename(src.relpath)
        if ".j2." not in basename:
            return None
        try:
            return J2Page(self, src)
        except IgnorePage:
            return None


class J2Page(Page):
    TYPE = "jinja2"

    RENDER_PREFERRED_ORDER = 2

    def __init__(self, j2env, src):
        dirname, basename = os.path.split(src.relpath)
        dst_basename = basename.replace(".j2", "")
        dst_relpath = os.path.join(dirname, dst_basename)

        if dst_basename == "index.html":
            linkpath = dirname
        else:
            linkpath = os.path.join(dirname, dst_basename)

        super().__init__(
            site=j2env.site,
            src=src,
            src_linkpath=linkpath,
            dst_relpath=dst_relpath,
            dst_link=os.path.join(j2env.site.settings.SITE_ROOT, linkpath))

        self.meta["date"] = self.site.generation_time

    def render(self):
        with open(self.src.abspath, "rt") as fd:
            template_body = fd.read()
        try:
            template = self.site.theme.jinja2.from_string(template_body)
        except Exception:
            log.exception("%s: cannot load template", self.src.relpath)
            raise IgnorePage
        body = template.render(
            page=self,
        )
        return {
            self.dst_relpath: RenderedString(body),
        }


FEATURES = {
    "j2": J2Pages,
}
